package
Version:
v0.3.2
Opens a new window with list of versions in this module.
Published: May 16, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Done(format string, a ...interface{})
Done prints a done message.
func Fail(format string, a ...interface{})
Fail prints a fail message.
Fatal prints a fatal error message and exits the program.
func Note(format string, a ...interface{})
Note prints a note message.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.